@@ -14,13 +14,13 @@
 #    under the License.
 
 from functools import cmp_to_key
+from functools import wraps
 import netaddr
 from oslo_config import cfg
 import oslo_i18n
 from oslo_log import log as logging
 from oslo_policy import policy as oslo_policy
-from six import iteritems
-from six.moves.urllib import parse as urllib_parse
+from urllib import parse as urllib_parse
 from webob import exc
 
 from tacker._i18n import _
@@ -31,17 +31,41 @@ from tacker import wsgi
 LOG = logging.getLogger(__name__)
 
 
+def validate_supported_params(supported_params):
+    """Decorator for Restful API methods which specifies supported parameters.
+
+    If there are unsupported parameters in the request parameters, the http
+    code 400 Bad Request will be returned and the user will be told which
+    parameters in the request are not supported.
+    """
+    def decorator(f):
+        @wraps(f)
+        def wrapped(*args, **kwargs):
+            request = kwargs.get('request')
+            if not request:
+                request = args[1]
+            params = set(request.params.keys())
+            unsupported_params = params - supported_params
+            if unsupported_params:
+                msg = _("Not supported parameters: %s") \
+                    % ','.join(unsupported_params)
+                raise exc.HTTPBadRequest(explanation=msg)
+            return f(*args, **kwargs)
+        return wrapped
+    return decorator
+
+
 def get_filters(request, attr_info, skips=None):
     """Extract the filters from the request string.
 
     Returns a dict of lists for the filters:
     check=a&check=b&name=Bob&
     becomes:
-    {'check': [u'a', u'b'], 'name': [u'Bob']}
+    {'check': ['a', 'b'], 'name': ['Bob']}
     """
     res = {}
     skips = skips or []
-    for key, values in iteritems(request.GET.dict_of_lists()):
+    for key, values in request.GET.dict_of_lists().items():
         if key in skips:
             continue
         values = [v for v in values if v]
@@ -232,7 +256,7 @@ class PaginationEmulatedHelper(PaginationHelper):
 class PaginationNativeHelper(PaginationEmulatedHelper):
 
     def update_args(self, args):
-        if self.primary_key not in dict(args.get('sorts', [])).keys():
+        if self.primary_key not in dict(args.get('sorts', [])):
             args.setdefault('sorts', []).append((self.primary_key, True))
         args.update({'limit': self.limit, 'marker': self.marker,
                      'page_reverse': self.page_reverse})
@@ -269,7 +293,7 @@ class SortingEmulatedHelper(SortingHelper):
     def update_fields(self, original_fields, fields_to_add):
         if not original_fields:
             return
-        for key in dict(self.sort_dict).keys():
+        for key in dict(self.sort_dict):
             if key not in original_fields:
                 original_fields.append(key)
                 fields_to_add.append(key)
