@@ -31,7 +31,35 @@ OPTS = [
     cfg.IntOpt(
         'retry_wait',
         default=10,
-        help="Retry interval(sec)")]
+        help="Retry interval (sec)"),
+    cfg.IntOpt(
+        'retry_timeout',
+        default=10,
+        help="Retry timeout (sec)"),
+    cfg.BoolOpt(
+        'test_callback_uri',
+        default=True,
+        help="Test callbackUri"),
+    cfg.IntOpt(
+        'operation_timeout',
+        default=60,
+        help="LCM operation timeout (sec)"),
+    cfg.BoolOpt(
+        'verify_notification_ssl',
+        default=True,
+        help="Verify the certificate to send notification by ssl"),
+    cfg.IntOpt(
+        'lcm_op_occ_num',
+        default=100,
+        help="Number of lcm_op_occs contained in 1 page"),
+    cfg.IntOpt(
+        'vnf_instance_num',
+        default=100,
+        help="Number of vnf_instances contained in 1 page"),
+    cfg.IntOpt(
+        'nextpage_expiration_time',
+        default=3600,
+        help="Expiration time (sec) for paging")]
 
 vnf_lcm_group = cfg.OptGroup('vnf_lcm',
     title='vnf_lcm options',
