@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import os
 import time
 import yaml
 
@@ -100,16 +101,19 @@ class BaseTackerTest(base.BaseTestCase):
         cls.h_client = cls.heatclient()
         cls.glance_client = cls.glanceclient()
         cls.cinder_client = cls.cinderclient()
+        cls.nova_client = cls.novaclient()
 
     @classmethod
-    def get_credentials(cls):
-        vim_params = yaml.safe_load(read_file('local-vim.yaml'))
+    def get_credentials(cls, vim_conf_file=None):
+        if vim_conf_file is None:
+            vim_conf_file = 'local-vim.yaml'
+        vim_params = yaml.safe_load(read_file(vim_conf_file))
         vim_params['auth_url'] += '/v3'
         return vim_params
 
     @classmethod
-    def get_auth_session(cls):
-        vim_params = cls.get_credentials()
+    def get_auth_session(cls, vim_conf_file=None):
+        vim_params = cls.get_credentials(vim_conf_file)
         auth = v3.Password(
             auth_url=vim_params['auth_url'],
             username=vim_params['username'],
@@ -122,20 +126,20 @@ class BaseTackerTest(base.BaseTestCase):
         return auth_ses
 
     @classmethod
-    def tacker_http_client(cls):
-        auth_session = cls.get_auth_session()
+    def tacker_http_client(cls, vim_conf_file=None):
+        auth_session = cls.get_auth_session(vim_conf_file)
         return SessionClient(session=auth_session,
                              service_type='nfv-orchestration',
                              region_name='RegionOne')
 
     @classmethod
-    def tackerclient(cls):
-        auth_session = cls.get_auth_session()
+    def tackerclient(cls, vim_conf_file=None):
+        auth_session = cls.get_auth_session(vim_conf_file)
         return tacker_client.Client(session=auth_session, retries=5)
 
     @classmethod
-    def novaclient(cls):
-        vim_params = cls.get_credentials()
+    def novaclient(cls, vim_conf_file=None):
+        vim_params = cls.get_credentials(vim_conf_file)
         auth = v3.Password(auth_url=vim_params['auth_url'],
             username=vim_params['username'],
             password=vim_params['password'],
@@ -148,8 +152,8 @@ class BaseTackerTest(base.BaseTestCase):
                                   session=auth_ses)
 
     @classmethod
-    def neutronclient(cls):
-        vim_params = cls.get_credentials()
+    def neutronclient(cls, vim_conf_file=None):
+        vim_params = cls.get_credentials(vim_conf_file)
         auth = v3.Password(auth_url=vim_params['auth_url'],
             username=vim_params['username'],
             password=vim_params['password'],
@@ -161,16 +165,18 @@ class BaseTackerTest(base.BaseTestCase):
         return neutron_client.Client(session=auth_ses)
 
     @classmethod
-    def heatclient(cls):
-        data = yaml.safe_load(read_file('local-vim.yaml'))
+    def heatclient(cls, vim_conf_file=None):
+        if vim_conf_file is None:
+            vim_conf_file = 'local-vim.yaml'
+        data = yaml.safe_load(read_file(vim_conf_file))
         data['auth_url'] = data['auth_url'] + '/v3'
         domain_name = data.pop('domain_name')
         data['user_domain_name'] = domain_name
         data['project_domain_name'] = domain_name
         return clients.OpenstackClients(auth_attr=data).heat
 
-    def blazarclient(cls):
-        data = cls.get_credentials()
+    def blazarclient(cls, vim_conf_file=None):
+        data = cls.get_credentials(vim_conf_file)
         domain_name = data.pop('domain_name')
         data['user_domain_name'] = domain_name
         data['project_domain_name'] = domain_name
@@ -185,8 +191,8 @@ class BaseTackerTest(base.BaseTestCase):
         return client
 
     @classmethod
-    def glanceclient(cls):
-        vim_params = cls.get_credentials()
+    def glanceclient(cls, vim_conf_file=None):
+        vim_params = cls.get_credentials(vim_conf_file)
         auth = v3.Password(auth_url=vim_params['auth_url'],
             username=vim_params['username'],
             password=vim_params['password'],
@@ -198,15 +204,15 @@ class BaseTackerTest(base.BaseTestCase):
         return glance_client.Client(session=auth_ses)
 
     @classmethod
-    def aodh_http_client(cls):
-        auth_session = cls.get_auth_session()
+    def aodh_http_client(cls, vim_conf_file=None):
+        auth_session = cls.get_auth_session(vim_conf_file)
         return SessionClient(session=auth_session,
                              service_type='alarming',
                              region_name='RegionOne')
 
     @classmethod
-    def cinderclient(cls):
-        vim_params = cls.get_credentials()
+    def cinderclient(cls, vim_conf_file=None):
+        vim_params = cls.get_credentials(vim_conf_file)
         auth = v3.Password(auth_url=vim_params['auth_url'],
             username=vim_params['username'],
             password=vim_params['password'],
@@ -447,3 +453,33 @@ class BaseTackerTest(base.BaseTestCase):
         self.validate_vnf_instance(vnfd_instance, vnf_instance)
 
         return vnf_instance, tosca_dict
+
+    def _list_op_occs(self, filter_string='', http_client=None):
+        if http_client is None:
+            http_client = self.http_client
+        show_url = os.path.join(
+            self.base_vnf_lcm_op_occs_url)
+        resp, response_body = http_client.do_request(
+            show_url + filter_string, "GET")
+        return resp, response_body
+
+    def _assert_occ_list(self, resp, op_occs_list):
+        self.assertEqual(200, resp.status_code)
+
+        # Only check required parameters.
+        for op_occs_info in op_occs_list:
+            self.assertIsNotNone(op_occs_info.get('id'))
+            self.assertIsNotNone(op_occs_info.get('operationState'))
+            self.assertIsNotNone(op_occs_info.get('stateEnteredTime'))
+            self.assertIsNotNone(op_occs_info.get('vnfInstanceId'))
+            self.assertIsNotNone(op_occs_info.get('operation'))
+            self.assertIsNotNone(op_occs_info.get('isAutomaticInvocation'))
+            self.assertIsNotNone(op_occs_info.get('isCancelPending'))
+
+            _links = op_occs_info.get('_links')
+            self.assertIsNotNone(_links.get('self'))
+            self.assertIsNotNone(_links.get('self').get('href'))
+            self.assertIsNotNone(_links.get('vnfInstance'))
+            self.assertIsNotNone(_links.get('vnfInstance').get('href'))
+            self.assertIsNotNone(_links.get('grant'))
+            self.assertIsNotNone(_links.get('grant').get('href'))
