@@ -15,8 +15,7 @@
 
 import codecs
 import os
-
-import mock
+from unittest import mock
 import yaml
 
 from oslo_serialization import jsonutils
@@ -24,7 +23,7 @@ from oslo_serialization import jsonutils
 from tacker import context
 from tacker.db.common_services import common_services_db_plugin
 from tacker.extensions import vnfm
-from tacker.tests.common import helpers
+from tacker.objects import fields
 from tacker.tests.unit import base
 from tacker.tests.unit.db import utils
 from tacker.vnfm.infra_drivers.openstack import openstack
@@ -49,7 +48,7 @@ vnf_dict = {
                     'properties': {
                         'user_data_format': 'SOFTWARE_CONFIG',
                         'availability_zone': 'nova',
-                        'image': 'cirros-0.4.0-x86_64-disk',
+                        'image': 'cirros-0.5.2-x86_64-disk',
                         'config_drive': False,
                         'flavor': {'get_resource': 'VDU1_flavor'},
                         'networks': [{'port': {'get_resource': 'CP1'}}]
@@ -84,8 +83,8 @@ class FakeHeatClient(mock.Mock):
 
     class Stack(mock.Mock):
         stack_status = 'CREATE_COMPLETE'
-        outputs = [{u'output_value': u'192.168.120.31', u'description':
-            u'management ip address', u'output_key': u'mgmt_ip-vdu1'}]
+        outputs = [{'output_value': '192.168.120.31', 'description':
+            'management ip address', 'output_key': 'mgmt_ip-vdu1'}]
 
     def create(self, *args, **kwargs):
         return {'stack': {'id': '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}}
@@ -148,114 +147,61 @@ class TestOpenStack(base.TestCase):
                 'tenant_id': 'ad7ebc56538745a08ef7c5e97f8bd437',
                 'id': 'fb048660-dc1b-4f0f-bd89-b023666650ec'}
 
-    def _get_expected_fields(self):
-        return {'stack_name':
-                'test_openwrt_eb84260e-5ff7-4332-b032-50a14d6c1123',
-                'template': self.hot_template}
-
-    def _get_expected_fields_user_data(self):
-        return {'stack_name':
-                'test_userdata_18685f68-2b2a-4185-8566-74f54e548811',
-                'template': self.hot_param_template}
-
-    def _get_expected_fields_ipaddr_data(self):
-        return {'stack_name': 'test_ip_d1337add-d5a1-4fd4-9447-bb9243c8460b',
-                'template': self.hot_ipparam_template}
-
-    def _get_expected_vnf_wait_obj(self, param_values=''):
-        return {'status': 'PENDING_CREATE',
-                'instance_id': None,
-                'name': u'test_openwrt',
-                'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
-                'vnfd_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
-                'vnfd': {
-                    'service_types': [{
-                        'service_type': u'vnfd',
-                        'id': u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}],
-                    'description': u'OpenWRT with services',
-                    'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
-                    'mgmt_driver': u'openwrt',
-                    'attributes': {u'vnfd': self.tosca_vnfd_openwrt},
-                    'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec',
-                    'name': u'OpenWRT'},
-                'mgmt_ip_address': '{"vdu1": "192.168.120.31"}',
-                'service_context': [],
-                'attributes': {u'param_values': param_values},
-                'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
-                'description': u'OpenWRT with services'}
-
     def _get_expected_vnf_update_obj(self):
         return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
-            u'test_openwrt', 'tenant_id':
-        u'ad7ebc56538745a08ef7c5e97f8bd437', 'vnfd_id':
-        u'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'vnfd': {
-            'service_types': [{'service_type': u'vnfd', 'id':
-            u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
-            u'OpenWRT with services', 'tenant_id':
-            u'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': u'openwrt',
-            'attributes': {u'vnfd': self.tosca_vnfd_openwrt},
-            'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
-            u'openwrt_services'}, 'mgmt_ip_address': None,
+             'test_openwrt', 'tenant_id':
+        'ad7ebc56538745a08ef7c5e97f8bd437', 'vnfd_id':
+        'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'vnfd': {
+            'service_types': [{'service_type': 'vnfd', 'id':
+            '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
+            'OpenWRT with services', 'tenant_id':
+            'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': 'openwrt',
+            'attributes': {'vnfd': self.tosca_vnfd_openwrt},
+            'id': 'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
+            'openwrt_services'}, 'mgmt_ip_address': None,
             'service_context': [],
             'attributes': {'config': utils.update_config_data},
             'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123', 'description':
-                u'OpenWRT with services'}
-
-    def _get_expected_vnf_update_param_obj(self):
-        return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
-            u'test_openwrt', 'tenant_id':
-        u'ad7ebc56538745a08ef7c5e97f8bd437', 'vnfd_id':
-        u'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'vnfd': {
-            'service_types': [{'service_type': u'vnfd', 'id':
-            u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
-            u'OpenWRT with services', 'tenant_id':
-            u'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': u'openwrt',
-            'attributes': {u'vnfd': self.tosca_vnfd_openwrt_param},
-            'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
-            u'openwrt_services'}, 'mgmt_url': None, 'service_context': [],
-            'attributes': {'heat_template': utils.hot_data,
-                           'param_values': utils.update_param_data},
-            'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123', 'description':
-                u'OpenWRT with services'}
+                'OpenWRT with services'}
 
     def _get_expected_vnf_update_new_param_obj(self):
         return {'status': 'PENDING_CREATE', 'instance_id': None, 'name':
-            u'test_openwrt', 'tenant_id':
-        u'ad7ebc56538745a08ef7c5e97f8bd437', 'vnfd_id':
-        u'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'vnfd': {
-            'service_types': [{'service_type': u'vnfd', 'id':
-            u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
-            u'OpenWRT with services', 'tenant_id':
-            u'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': u'openwrt',
-            'attributes': {u'vnfd': self.tosca_vnfd_openwrt_param},
-            'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
-            u'openwrt_services'}, 'mgmt_url': None, 'service_context': [],
+            'test_openwrt', 'tenant_id':
+        'ad7ebc56538745a08ef7c5e97f8bd437', 'vnfd_id':
+        'eb094833-995e-49f0-a047-dfb56aaf7c4e', 'vnfd': {
+            'service_types': [{'service_type': 'vnfd', 'id':
+            '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}], 'description':
+            'OpenWRT with services', 'tenant_id':
+            'ad7ebc56538745a08ef7c5e97f8bd437', 'mgmt_driver': 'openwrt',
+            'attributes': {'vnfd': self.tosca_vnfd_openwrt_param},
+            'id': 'fb048660-dc1b-4f0f-bd89-b023666650ec', 'name':
+            'openwrt_services'}, 'mgmt_url': None, 'service_context': [],
             'attributes': {'heat_template': utils.hot_data,
                            'param_values': utils.update_new_param_data},
             'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123', 'description':
-                u'OpenWRT with services'}
+                'OpenWRT with services'}
 
     def _get_expected_active_vnf(self):
         return {'status': 'ACTIVE',
                 'instance_id': None,
-                'name': u'test_openwrt',
-                'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
-                'vnfd_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
+                'name': 'test_openwrt',
+                'tenant_id': 'ad7ebc56538745a08ef7c5e97f8bd437',
+                'vnfd_id': 'eb094833-995e-49f0-a047-dfb56aaf7c4e',
                 'vnfd': {
                     'service_types': [{
-                        'service_type': u'vnfd',
-                        'id': u'4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}],
-                    'description': u'OpenWRT with services',
-                    'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437',
-                    'mgmt_driver': u'openwrt',
-                    'infra_driver': u'heat',
-                    'attributes': {u'vnfd': self.tosca_vnfd_openwrt},
-                    'id': u'fb048660-dc1b-4f0f-bd89-b023666650ec',
-                    'name': u'openwrt_services'},
+                        'service_type': 'vnfd',
+                        'id': '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'}],
+                    'description': 'OpenWRT with services',
+                    'tenant_id': 'ad7ebc56538745a08ef7c5e97f8bd437',
+                    'mgmt_driver': 'openwrt',
+                    'infra_driver': 'heat',
+                    'attributes': {'vnfd': self.tosca_vnfd_openwrt},
+                    'id': 'fb048660-dc1b-4f0f-bd89-b023666650ec',
+                    'name': 'openwrt_services'},
                 'mgmt_ip_address': '{"vdu1": "192.168.120.31"}',
                 'service_context': [],
                 'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
-                'description': u'OpenWRT with services'}
+                'description': 'OpenWRT with services'}
 
     def test_delete(self):
         vnf_id = '4a4c2d44-8a52-4895-9a75-9d1c76c3e738'
@@ -346,7 +292,8 @@ class TestOpenStack(base.TestCase):
     def _get_expected_fields_tosca(self, template):
         return {'stack_name':
                 'test_openwrt_eb84260e-5ff7-4332-b032-50a14d6c1123',
-                'template': _get_template(template)}
+                'template': _get_template(template),
+                'timeout_mins': 10}
 
     def _get_expected_tosca_vnf(self,
                                 tosca_tpl_name,
@@ -359,7 +306,7 @@ class TestOpenStack(base.TestCase):
         tosca_hw_dict = yaml.safe_load(_get_template(hot_tpl_name))
         dvc = {
             'vnfd': exp_tmpl,
-            'description': u'OpenWRT with services',
+            'description': 'OpenWRT with services',
             'attributes': {
                 'heat_template': tosca_hw_dict,
                 'param_values': param_values
@@ -367,17 +314,17 @@ class TestOpenStack(base.TestCase):
             'id': 'eb84260e-5ff7-4332-b032-50a14d6c1123',
             'instance_id': None,
             'mgmt_ip_address': None,
-            'name': u'test_openwrt',
+            'name': 'test_openwrt',
             'service_context': [],
             'status': 'PENDING_CREATE',
-            'vnfd_id': u'eb094833-995e-49f0-a047-dfb56aaf7c4e',
-            'tenant_id': u'ad7ebc56538745a08ef7c5e97f8bd437'
+            'vnfd_id': 'eb094833-995e-49f0-a047-dfb56aaf7c4e',
+            'tenant_id': 'ad7ebc56538745a08ef7c5e97f8bd437'
         }
         # Add monitoring attributes for those yaml, which are having it
         if is_monitor:
             if multi_vdus:
                 dvc['attributes'].update(
-                    {'monitoring_policy': helpers.compact_byte(
+                    {'monitoring_policy': bytes(
                      '{"vdus": {"VDU1": {"ping": '
                      '{"name": "ping", "actions": '
                      '{"failure": "respawn"}, '
@@ -390,10 +337,10 @@ class TestOpenStack(base.TestCase):
                      '"parameters": {"count": 3, '
                      '"interval": 10}, '
                      '"monitoring_params": {"count": 3, '
-                     '"interval": 10}}}}}')})
+                     '"interval": 10}}}}}', 'utf-8')})
             else:
                 dvc['attributes'].update(
-                    {'monitoring_policy': helpers.compact_byte(
+                    {'monitoring_policy': bytes(
                      '{"vdus": {"VDU1": {"ping": '
                      '{"name": "ping", "actions": '
                      '{"failure": "respawn"}, '
@@ -401,7 +348,7 @@ class TestOpenStack(base.TestCase):
                      '"interval": 10}, '
                      '"monitoring_params": '
                      '{"count": 3, '
-                     '"interval": 10}}}}}')})
+                     '"interval": 10}}}}}', 'utf-8')})
 
         return dvc
 
@@ -431,9 +378,11 @@ class TestOpenStack(base.TestCase):
                                                     input_params,
                                                     is_monitor,
                                                     multi_vdus)
+        vnf['before_error_point'] = fields.ErrorPoint.PRE_VIM_CONTROL
         result = self.infra_driver.create(plugin=None, context=self.context,
                                          vnf=vnf,
                                          auth_attr=utils.get_vim_auth_obj())
+        del vnf['before_error_point']
         actual_fields = self.heat_client.create.call_args[0][0]
         actual_fields["template"] = yaml.safe_load(actual_fields["template"])
         expected_fields["template"] = \
@@ -579,7 +528,7 @@ class TestOpenStack(base.TestCase):
     def test_tosca_artifacts_image_params(self):
         input_params = 'image_source: ' \
                        'http://download.cirros-cloud.net/' \
-                       '0.4.0/cirros-0.4.0-x86_64-disk.img'
+                       '0.5.2/cirros-0.5.2-x86_64-disk.img'
         self._test_assert_equal_for_tosca_templates(
             'tosca_artifacts_image_vnfd_params.yaml',
             'hot_tosca_artifacts_image_vnfd_params.yaml',
