@@ -12,16 +12,18 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from unittest import mock
+
 
 import ddt
+from http import client as http_client
 import json
 import os
-from oslo_serialization import jsonutils
-from six.moves import http_client
-from six.moves import urllib
+from unittest import mock
+import urllib
 from webob import exc
 
+from oslo_serialization import jsonutils
+
 from tacker.api.vnfpkgm.v1 import controller
 from tacker.common import exceptions as tacker_exc
 from tacker.conductor.conductorrpc.vnf_pkgm_rpc import VNFPackageRPCAPI
@@ -60,13 +62,16 @@ class TestController(base.TestCase):
 
     @mock.patch.object(vnf_package, '_vnf_package_create')
     @mock.patch.object(vnf_package.VnfPackage, '_from_db_object')
-    def test_create_with_status_202(self, mock_from_db, mock_vnf_pack):
+    def test_create_with_status_201(self, mock_from_db, mock_vnf_pack):
         body = {'userDefinedData': {'abc': 'xyz'}}
         req = fake_request.HTTPRequest.blank('/vnf_packages')
         req.body = jsonutils.dump_as_bytes(body)
         req.headers['Content-Type'] = 'application/json'
         req.method = 'POST'
         resp = req.get_response(self.app)
+        location_pattern = (r'http://localhost/vnfpkgm/v1/vnf_packages/'
+                            r'([a-f]|\d|-){36}')
+        self.assertRegex(resp.headers['location'], location_pattern)
         self.assertEqual(http_client.CREATED, resp.status_code)
 
     @mock.patch.object(vnf_package, '_vnf_package_create')
@@ -79,6 +84,9 @@ class TestController(base.TestCase):
         req.headers['Content-Type'] = 'application/json'
         req.method = 'POST'
         resp = req.get_response(self.app)
+        location_pattern = (r'http://localhost/vnfpkgm/v1/vnf_packages/'
+                            r'([a-f]|\d|-){36}')
+        self.assertRegex(resp.headers['location'], location_pattern)
         self.assertEqual(http_client.CREATED, resp.status_code)
 
     @mock.patch.object(VnfSoftwareImage, 'get_by_id')
@@ -260,12 +268,12 @@ class TestController(base.TestCase):
 
     @mock.patch.object(VnfPackagesList, "get_by_filters")
     @ddt.data(
-        {'filter': '(eq,vnfdId,dummy_vnfd_id)'},
-        {'filter': '(in,vnfdId,dummy_vnfd_id)'},
-        {'filter': '(cont,vnfdId,dummy_vnfd_id)'},
-        {'filter': '(neq,vnfdId,dummy_vnfd_id)'},
-        {'filter': '(nin,vnfdId,dummy_vnfd_id)'},
-        {'filter': '(ncont,vnfdId,dummy_vnfd_id)'},
+        {'filter': '(eq,vnfdId,%s)' % constants.UUID},
+        {'filter': '(in,vnfdId,%s)' % constants.UUID},
+        {'filter': '(cont,vnfdId,%s)' % constants.UUID},
+        {'filter': '(neq,vnfdId,%s)' % constants.UUID},
+        {'filter': '(nin,vnfdId,%s)' % constants.UUID},
+        {'filter': '(ncont,vnfdId,%s)' % constants.UUID},
         {'filter': '(gt,softwareImages/createdAt,2020-03-11 04:10:15+00:00)'},
         {'filter': '(gte,softwareImages/createdAt,2020-03-14 04:10:15+00:00)'},
         {'filter': '(lt,softwareImages/createdAt,2020-03-20 04:10:15+00:00)'},
@@ -300,7 +308,8 @@ class TestController(base.TestCase):
     @mock.patch.object(VnfPackagesList, "get_by_filters")
     def test_index_filter_combination(self, mock_vnf_list):
         """Test multiple filter parameters separated by semicolon """
-        params = {'filter': '(eq,vnfdId,dummy_vnfd_id);(eq,id,dummy_id)'}
+        params = {'filter': '(eq,vnfdId,%s);(eq,id,%s)' %
+                  (constants.UUID, constants.UUID)}
         query = urllib.parse.urlencode(params)
         req = fake_request.HTTPRequest.blank('/vnfpkgm/v1/vnf_packages?' +
             query)
@@ -316,8 +325,8 @@ class TestController(base.TestCase):
 
     @mock.patch.object(VnfPackagesList, "get_by_filters")
     @ddt.data(
-        {'filter': '(eq,id,dummy_value)'},
-        {'filter': '(eq,vnfdId,dummy_value)'},
+        {'filter': '(eq,id,%s)' % constants.UUID},
+        {'filter': '(eq,vnfdId,%s)' % constants.UUID},
         {'filter': '(eq,onboardingState,ONBOARDED)'},
         {'filter': '(eq,operationalState,ENABLED)'},
         {'filter': '(eq,usageState,NOT_IN_USE)'},
@@ -328,7 +337,7 @@ class TestController(base.TestCase):
         {'filter': '(eq,userDefinedData/key1,dummy_value)'},
         {'filter': '(eq,checksum/algorithm,dummy_value)'},
         {'filter': '(eq,checksum/hash,dummy_value)'},
-        {'filter': '(eq,softwareImages/id,dummy_value)'},
+        {'filter': '(eq,softwareImages/id,%s)' % constants.UUID},
         {'filter': '(eq,softwareImages/imagePath,dummy_value)'},
         {'filter': '(eq,softwareImages/diskFormat,dummy_value)'},
         {'filter': '(eq,softwareImages/userMetadata/key3,dummy_value)'},
@@ -462,6 +471,8 @@ class TestController(base.TestCase):
 
     @mock.patch.object(VnfPackagesList, "get_by_filters")
     @ddt.data(
+        {'filter': '(eq,id,fake_value)'},
+        {'filter': '(eq,vnfd_id,fake_value)'},
         {'filter': '(eq,operationalState,fake_value)'},
         {'filter': '(eq,softwareImages/size,fake_value)'},
         {'filter': '(gt,softwareImages/createdAt,fake_value)'},
@@ -990,7 +1001,8 @@ class TestController(base.TestCase):
 
     def test_fetch_vnf_package_content_valid_range(self):
         request = fake_request.HTTPRequest.blank(
-            '/vnf_packages/%s/package_content/')
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
         request.headers["Range"] = 'bytes=10-99'
         range_ = self.controller._get_range_from_request(request, 120)
         self.assertEqual(10, range_.start)
@@ -998,7 +1010,8 @@ class TestController(base.TestCase):
 
     def test_fetch_vnf_package_content_invalid_range(self):
         request = fake_request.HTTPRequest.blank(
-            '/vnf_packages/%s/package_content/')
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
         request.headers["Range"] = 'bytes=150-'
         self.assertRaises(exc.HTTPRequestRangeNotSatisfiable,
                           self.controller._get_range_from_request,
@@ -1006,12 +1019,96 @@ class TestController(base.TestCase):
 
     def test_fetch_vnf_package_content_invalid_multiple_range(self):
         request = fake_request.HTTPRequest.blank(
-            '/vnf_packages/%s/package_content/')
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
         request.headers["Range"] = 'bytes=10-20,21-30'
         self.assertRaises(exc.HTTPBadRequest,
                           self.controller._get_range_from_request, request,
                           120)
 
+    @mock.patch.object(controller.VnfPkgmController, "_download")
+    @mock.patch.object(controller.VnfPkgmController, "_get_range_from_request")
+    @mock.patch.object(glance_store, 'get_csar_size')
+    @mock.patch.object(controller.VnfPkgmController, '_get_vnf_package')
+    @mock.patch.object(vnf_package.VnfPackage, 'save')
+    def test_fetch_vnf_package_content(
+            self,
+            mock_save,
+            mock_get_vnf_package,
+            mock_get_csar_size,
+            mock_get_range,
+            mock_download):
+        request = fake_request.HTTPRequest.blank(
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
+        request.headers["Range"] = 'bytes=10-20,21-30'
+        request.response = ""
+        mock_get_vnf_package.return_value = fakes.return_vnfpkg_obj()
+        mock_get_csar_size.return_value = 1000
+        mock_get_range.return_value = "10-20, 21-30"
+        mock_download.return_value = "Response"
+        id = constants.UUID
+        result = self.controller.fetch_vnf_package_content(request, id)
+        self.assertEqual(result, "Response")
+        mock_get_csar_size.assert_called_once_with(
+            id, fakes.return_vnfpkg_obj().location_glance_store)
+        mock_get_vnf_package.assert_called_once_with(
+            id, request)
+        mock_get_range.assert_called_once_with(
+            request, 1000)
+
+    @mock.patch.object(controller.VnfPkgmController, '_get_vnf_package')
+    def test_fetch_vnf_package_content_invalid_onboarding(
+            self, mock_get):
+        request = fake_request.HTTPRequest.blank(
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
+        request.headers["Range"] = 'bytes=10-20,21-30'
+        request.response = ""
+        pkgobj = fakes.return_vnfpkg_obj()
+        pkgobj.onboarding_state = fields.PackageOnboardingStateType.PROCESSING
+        mock_get.return_value = pkgobj
+        id = constants.UUID
+        self.assertRaises(exc.HTTPConflict,
+                          self.controller.fetch_vnf_package_content, request,
+                          id)
+
+    @mock.patch.object(controller.VnfPkgmController, '_get_vnf_package')
+    def test_fetch_vnf_package_content_not_present(self, mock_get):
+        request = fake_request.HTTPRequest.blank(
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
+        request.headers["Range"] = 'bytes=10-20,21-30'
+        request.response = ""
+        pkgobj = fakes.return_vnfpkg_obj()
+        mock_get.return_value = pkgobj
+        id = constants.UUID
+        self.assertRaises(exc.HTTPNotFound,
+                          self.controller.fetch_vnf_package_content, request,
+                          id)
+
+    @mock.patch.object(controller.VnfPkgmController, "_download")
+    @mock.patch.object(controller.VnfPkgmController, "_get_range_from_request")
+    @mock.patch.object(controller.VnfPkgmController, '_get_vnf_package')
+    def test_fetch_vnf_package_content_with_size(
+            self,
+            mock_get,
+            mock_get_range,
+            mock_download):
+        request = fake_request.HTTPRequest.blank(
+            '/vnf_packages/%s/package_content/'
+            % constants.UUID)
+        request.headers["Range"] = 'bytes=10-20,21-30'
+        request.response = ""
+        pkgobj = fakes.return_vnfpkg_obj()
+        pkgobj.size = 1000
+        mock_get_range.return_value = "10-20, 21-30"
+        mock_download.return_value = 1000
+        mock_get.return_value = pkgobj
+        id = constants.UUID
+        result = self.controller.fetch_vnf_package_content(request, id)
+        self.assertEqual(result, 1000)
+
     def test_fetch_vnf_package_artifacts_with_invalid_uuid(
             self):
         # invalid_uuid
